@@ -10,6 +10,7 @@ from torch.nn import CrossEntropyLoss, MSELoss, BCEWithLogitsLoss
 from transformers import BertConfig, BertTokenizerFast
 from transformers.modeling_bert import BertPreTrainedModel, BertModel
 from sklearn.metrics import classification_report, roc_auc_score
+import mlflow
 
 from ..trainer import Trainer, get_default_optimizer_parameters
 from ...losses import FocalLoss
@@ -243,8 +244,8 @@ class BertForSequenceClassification(BertPreTrainedModel):
             return (loss, ) + outputs
         else:
             # (loss), logits, (hidden_states), (attentions)
-            #  return (torch.tensor(0.0).cuda(), ) + outputs
-            return outputs
+            return (torch.tensor(0.0).cuda(), ) + outputs
+            #  return outputs
 
 MODEL_CLASSES = {
     'bert': (BertConfig, BertForSequenceClassification, BertTokenizerFast),
@@ -485,6 +486,11 @@ class GlueTrainer(Trainer):
             result = acc_and_f1(self.preds,
                                 np.argmax(self.out_label_ids, axis=1))
 
+        if args.do_experiment:
+            mlflow.log_metric('loss', eval_loss.item())
+            for key, value in result.items():
+                mlflow.log_metric(key, value)
+
         self.results.update(result)
 
         return (eval_loss, ), self.results
@@ -526,7 +532,8 @@ class GlueTrainer(Trainer):
 
         #  logger.debug(f"inputs: {inputs}")
         #  logger.debug(f"outputs: {outputs}")
-        logits = outputs[0]
+        logits = outputs[1]
+        #  logits = outputs[0]
         if self.logits is None:
             self.logits = logits.detach().cpu().numpy()
         else:
