@@ -3,6 +3,7 @@
 
 import numpy as np
 from loguru import logger
+import mlflow
 
 import torch
 import torch.nn as nn
@@ -317,8 +318,8 @@ class BertCrfForNer(BertPreTrainedModel):
             return outputs
         else:
             #  return (0.0, ) + outputs  # (loss), scores
-            #  return (torch.tensor(0.0).cuda(), ) + outputs
-            return outputs
+            return (torch.tensor(0.0).cuda(), ) + outputs
+            #  return outputs
 
 
 #  from transformers import AlbertConfig
@@ -699,6 +700,11 @@ class NerTrainer(Trainer):
         eval_info, _ = self.metric.result()
         results = {f'{key}': value for key, value in eval_info.items()}
 
+        if args.do_experiment:
+            mlflow.log_metric('loss', loss)
+            for key, value in eval_info.items():
+                mlflow.log_metric(key, value)
+
         #  batch_preds = tags
         #  for i in range(len(batch_preds)):
         #      preds = batch_preds[i]
@@ -719,8 +725,9 @@ class NerTrainer(Trainer):
         attention_mask = inputs['attention_mask']
 
         outputs = model(**inputs)
-        #  logits = outputs[0][1]
-        logits = outputs[0]
+        #  logger.debug(f"outputs: {outputs}")
+        logits = outputs[1]
+        #  logits = outputs[0]
 
         # --------------------------------------
         # NCRFPP CRF
